@@ -1,7 +1,10 @@
 import base64
+import operator
+from functools import reduce
 from django.conf import settings
 from rest_framework import serializers
 from Crypto.Cipher import AES
+from django.db import models
 
 
 def encrypt(texto_plano: str) -> str:
@@ -30,3 +33,23 @@ def decrypt(enc: str) -> str:
     obj2 = AES.new(key, AES.MODE_CFB, vector)
     decrypted_text = obj2.decrypt(base64.b64decode(enc)).decode("utf-8")
     return decrypted_text
+
+
+def search_multiple_fields(queryset, search_fields, parameter):
+    def construct_search(field_name):
+        if field_name.startswith('^'):
+            return "%s__istartswith" % field_name[1:]
+        elif field_name.startswith('='):
+            return "%s__iexact" % field_name[1:]
+        elif field_name.startswith('@'):
+            return "%s__search" % field_name[1:]
+        else:
+            return "%s__icontains" % field_name
+
+    orm_lookups = [construct_search(str(search_field))
+                   for search_field in search_fields]
+    for bit in parameter.split():
+        or_queries = [models.Q(**{orm_lookup: bit})
+                      for orm_lookup in orm_lookups]
+        queryset = queryset.filter(reduce(operator.or_, or_queries))
+    return queryset
